@@ -22,8 +22,7 @@ def test_reduced_gg():
     plt.colorbar(cs, shrink=0.6)
     ax.coastlines()
     gl = ax.gridlines(draw_labels=True)
-    gl.ylabels_top = False; gl.xlabels_top = False
-    gl.ylabels_right = False; gl.xlabels_right = False
+    gl.right_labels = False; gl.top_labels = False
     plt.title(grb.parameterName+' on ECMWF Reduced Gaussian Grid')
     return fig
 
